Learn R Programming

tsxtreme (version 0.3.4)

bayesfit: Traces from MCMC output

Description

Test or show objects of class "bayesfit".

Usage

is.bayesfit(x)

Value

An object of class "bayesfit" is a list containing MCMC traces for:

a,b

Heffernan-Tawn parameters.

sd,mean,w

standard deviations, means and weights of the mixture components.

prec

precision parameter of the Dirichlet process.

ci

auxiliary variable; components' indices for each observation.

noo

number of observations in each mixture component.

noc

number of non-empty components in the mixture.

prop.sd

standard deviations of the proposal distributions for a and b.

And len, the length of the traces, i.e., the number of iterations saved.

Arguments

x

an arbitrary R object.

Details

Default plot shows samples of residual densities (which==1), residual distribution with credible interval (\(5\%\) and \(95\%\) posterior quantiles; which==2), and joint posterior distribution of \(\alpha\) and \(\beta\) (which==3) for each lag successively. which can be any composition of 1,2 and 3.

See Also

bayesparams, stepfit