Learn R Programming

tsxtreme (version 0.3.4)

depmeasure: Dependence measures estimates

Description

Test or show objects of class "depmeasure".

Usage

is.depmeasure(x)

Value

An object of class 'depmeasure' is a list which contains:

fit

an object of class 'bayesfit'

distr

an array with the samples used for the estimation.

probs,levels

points ---probability and original scale respectively--- at which the dependence measure is estimated

Depending on the dependence measure, theta or chi, a matrix with levels on row-entries and mean, median and specified quantiles of the posterior distribution of theta or chi respectively.

Arguments

x

an arbitrary R object.

See Also

depmeasures