Learn R Programming

tsxtreme (version 0.3.4)

tsxtreme-package: tools:::Rd_package_title("tsxtreme")

Description

tools:::Rd_package_description("tsxtreme")

Arguments

Author

tools:::Rd_package_author("tsxtreme")

Maintainer: tools:::Rd_package_maintainer("tsxtreme")

Details

tools:::Rd_package_indices("tsxtreme") The Heffernan--Tawn conditional formulation for a stationary time series \((X_t)\) with Laplace marginal distribution states that for a large enough threshold \(u\) there exist scale parameters \(-1 \le\alpha_j\le 1\) and \(0 \le \beta_j \le 1\) such that $$Pr\left(\frac{X_j-\alpha_j X_0}{(X_j)^{\beta_j}} < z_j, j=1,\ldots,m \mid X_0 > u\right) = H(z_1,\ldots,z_m),$$

with \(H\) non-degenerate; the equality holds exactly only when \(u\) tends to infinity.

There are mainly 3 functions provided by this package, which allow estimation of extremal dependence measures and fitting the Heffernan--Tawn model using Dirichlet processes.

depfit fits the Heffernan--Tawn model using a Bayesian semi-parametric approach.

thetafit computes posterior samples of the threshold-based index of Ledford and Tawn (2003) based on inference in depfit.

chifit computes posterior samples of the extremal measure of dependence of Coles, Heffernan and Tawn (1999) at any extremal level.

Some corresponding functions using the stepwise approach of Heffernan and Tawn (2004) are also part of the package, namely dep2fit and theta2fit.

The empirical estimation of the extremal index can be done using thetaruns and some basic functions handling the Laplace distribution are also available in dlapl.

References

Coles, S., Heffernan, J. E. and Tawn, J. A. (1999) Dependence measures for extreme value analyses. Extremes, 2, 339--365.

Davison, A. C. and Smith, R. L. (1990) Models for exceedances over high thresholds. Journal of the Royal Statistical Society Series B, 52, 393--442.

Heffernan, J. E. and Tawn, J. A. (2004) A conditional approach for multivariate extreme values. Journal of the Royal Statistical Society Series B, 66, 497--546.

Ledford, W. A. and Tawn, J. A. (2003) Diagnostics for dependence within time series extremes. Journal of the Royal Statistical Society Series B, 65, 521--543.

Lugrin, T., Davison, A. C. and Tawn, J. A. (2016) Bayesian uncertainty management in temporal dependence of extremes. Extremes, 19, 491--515.

See Also

thetafit, chifit, depfit