Test or show objects of class "bayesfit".
is.bayesfit(x)An object of class "bayesfit" is a list containing MCMC traces for:
Heffernan-Tawn parameters.
standard deviations, means and weights of the mixture components.
precision parameter of the Dirichlet process.
auxiliary variable; components' indices for each observation.
number of observations in each mixture component.
number of non-empty components in the mixture.
standard deviations of the proposal distributions for a and b.
And len, the length of the traces, i.e., the number of iterations saved.
an arbitrary R object.
Default plot shows samples of residual densities (which==1), residual distribution with credible interval (\(5\%\) and \(95\%\) posterior quantiles; which==2), and joint posterior distribution of \(\alpha\) and \(\beta\) (which==3) for each lag successively. which can be any composition of 1,2 and 3.
bayesparams, stepfit