Test or show objects of class "depmeasure".
is.depmeasure(x)An object of class 'depmeasure' is a list which contains:
an object of class 'bayesfit'
an array with the samples used for the estimation.
points ---probability and original scale respectively--- at which the dependence measure is estimated
Depending on the dependence measure, theta or chi, a matrix with levels on row-entries and mean, median and specified quantiles of the posterior distribution of theta or chi respectively.
an arbitrary R object.
depmeasures